## [0.3.1] - 2024-2-7
- Bug Fix: Fix MANIFEST so template is included with distribution
- 
## [0.3.0] - 2023-12-15
- Enhancement: POST JWT back to Zendesk instead of GET 
- Removed deprecated "ZendeskAuthorize" view

## [0.2.0] - 2022-05-26
- Added: Django 2, 3, and 4 support
- Dropped: Django 1.11 support

## [0.1.1] - 2018-08-10
- Bug Fix: Decode JWT w/ Python 3

## [0.1.0] - 2017-05-19
- Added: Python3 Support and Django 1.8